import logo from './logo.svg';
import './App.css';
import { useEffect, useState, useRef } from 'react';

function App() {
  const [posts, setPosts] = useState([]);
  const [comments, setComments] = useState([]);
  const [postToEdit, setPostToEdit] = useState(null);
  const [postToComment, setPostToComment] = useState(null);
  const [selectedPost, setSelectedPost] = useState(null);
  const [loaded, setLoaded] = useState(false);
  const content = useRef(null);
  const editingContent = useRef(null);
  const comment = useRef(null);

  function getPosts() {
    fetch('http://localhost:8080/posts').then(response => {
      return response.json()
    }).then(json => {
      setPosts(json);
      console.log(json);
      setLoaded(true);
    })
  }

  useEffect(() => {
    getPosts();
  }, []);

  function putPost() {
    fetch('http://localhost:8080/put-post', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json'
      },
      body: JSON.stringify({
        user: 1,
        content: content.current.value
      })
    }).then(response => {
      if (response.ok) {
        content.current.value = '';
        getPosts();  
      } else {
        alert("You have no power here!")
      }
    }).catch(e => {
      console.error(e);
    });
  }

  function deletePost(id) {
    fetch('http://localhost:8080/delete-post', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json'
      },
      body: JSON.stringify({
        post: id
      })
    }).then(response => {
      getPosts();
    }).catch(e => {
      console.error(e);
    });
  }

  function submitEdit() {
    fetch('http://localhost:8080/update-post', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json'
      },
      body: JSON.stringify({
        post: postToEdit.post,
        content: editingContent.current.value
      })
    }).then(response => {
      if (response.ok) {
        getPosts();
        setPostToEdit(null); 
      }
    }).catch(e => {
      console.error(e);
    });
  }

  function getComments(post) {
    fetch(`http://localhost:8080/get-comments/${post}`).then(response => {
      return response.json()
    }).then(comms => {
      setComments(comms);
    }).catch(e => console.error(e));
  }

  function submitComment() {
    fetch('http://localhost:8080/put-comment', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json'
      },
      body: JSON.stringify({
        post: selectedPost.post,
        comment: comment.current.value,
        user: 1
      })
    }).then(response => {
      if (response.ok) {
        getComments(selectedPost.post);
        comment.current.value = "";
      }
    }).catch(e => {
      console.error(e);
    });
  }

  function selectPost(post) {
    setSelectedPost(post);
    if (post) {
      getComments(post.post);   
    } else {
      setComments([]);
    }
  }

  return (
    <div className="App">
      {loaded ? (
        <div className='container'>
          {selectedPost ? (
            <div>
              <button onClick={() => selectPost(null)}>Back</button>
              <div style={{ margin: 10, padding: 10, background: '#ffff00' }}>
                <h1>Post:</h1>
                <p>{selectedPost.content}</p>
                <div>
                  <h2>Comments:</h2>
                  {comments.map((comment) => (<p key={comment.id}>{comment.comment}</p>))}
                </div>
                <div style={{
                  margin: 40,
                  border: '1px solid red',
                  display: 'flex',
                  alignItems: 'center',
                  justifyContent: 'center'
                }}>
                  <textarea ref={comment} placeholder={"Put your comment here!"}></textarea>
                  <button onClick={submitComment}>Submit Comment</button>
                </div>
              </div>
            </div>
          ): (
              <div>
                {posts.map((post) => (
                  <div key={post.post} style={{margin: 10, padding: 10, background: '#ddd'}}>
                    <p>
                      {post.content}
                    </p>
                    
                    <button onClick={() => selectPost(post)}>View Post</button>
                    <button onClick={() => setPostToEdit(post)}>Edit</button>
                    <button onClick={() => deletePost(post.post)}>Delete</button>
                  </div>
                ))}
                <textarea ref={content}></textarea>
                <button onClick={putPost}>Send the post!!!!</button>    
              </div>
          )}
          

          {postToEdit && (
            <div style={{
              margin: 40,
              border: '1px solid blue',
              display: 'flex',
              alignItems: 'center',
              justifyContent: 'center'
            }}>
              <textarea ref={editingContent} defaultValue={postToEdit.content}></textarea>
              <button onClick={submitEdit}>Done Editing</button>
            </div>
          )}

          {postToComment && (
            <div style={{
              margin: 40,
              border: '1px solid red',
              display: 'flex',
              alignItems: 'center',
              justifyContent: 'center'
            }}>
              <textarea ref={comment} placeholder={"Put your comment here!"}></textarea>
              <button onClick={submitComment}>Submit Comment</button>
            </div>
          )}
        </div>
      ): (
          <h1>LOADING.....</h1>
      )}
      
     
    </div>
  );
}

export default App;
