const Mysql = require('./mysql-connection');

//all of these should take two parameters, req (data about the request), and res (functions that let us respond to the user)
function handleRoot(req, res) {
    res.send("Hello World!");
}

async function getPosts(req, res) {
    try {
        //write out your mysql query
        const query = `
            SELECT
                *
            FROM
                posts
        `;

        //gets the results from the mysql server
        let posts = await Mysql.query(query);

        //send the results to the user making the request
        res.send(posts);
    } catch (e) {

        //something went wrong, log the error, return a 500 Internal Server Error
        console.error(e);
        res.sendStatus(500);
    }
}

async function getComments(req, res) {
    try {
        const post = req.params.post;

        const query = `
            SELECT
                *
            FROM
                comments
            WHERE
                post = ?
        `;

        const comments = await Mysql.query(query, [post]);

        res.send(comments);
    } catch (e) {
        
        //something went wrong, log the error, return a 500 Internal Server Error
        console.error(e);
        res.sendStatus(500);
    }
}

async function putPost(req, res) {
    try {
        const content = req.body.content;
        const user = req.body.user;

        const checkQuery = `
            SELECT 
                id
            FROM
                users
            WHERE
                id = ?
            AND
                status = 1
        `;

        const users = await Mysql.query(checkQuery, [user]);
        
        if (users.length === 0) {
            console.log("User does not exist!!!");
            return res.sendStatus(403);
        }

        const query = `
            INSERT INTO
                posts
            SET
                content = ?,
                user = ?
        `;

        const results = await Mysql.query(query, [content, user]);

        res.sendStatus(200);
    } catch (e) {
        //something went wrong, log the error, return a 500 Internal Server Error
        console.error(e);
        res.sendStatus(500);
    }
}

async function deletePost(req, res) {
    try {
        const post = req.body.post;

        const myquery = `
            DELETE FROM
                posts
            WHERE
                post = ?
            LIMIT 1
        `;

        const results = await Mysql.query(myquery, [post]);

        res.sendStatus(200);
    } catch (e) {
        //something went wrong, log the error, return a 500 Internal Server Error
        console.error(e);
        res.sendStatus(500);
    }
}

async function updatePost(req, res) {
    try {
        const {
            post,
            content
        } = req.body;

        const query = `
            UPDATE
                posts
            SET
                content = ?
            WHERE
                post = ?
            LIMIT 1
        `;

        const results = await Mysql.query(query, [content, post]);

        res.sendStatus(200);
    } catch (e) {
        //something went wrong, log the error, return a 500 Internal Server Error
        console.error(e);
        res.sendStatus(500);
    }
}

async function putComment(req, res) {
    try {
        const {
            comment,
            post,
            user
        } = req.body;

        const query = `
            INSERT INTO
                comments
            SET
                comment = ?,
                user = ?,
                post = ?
        `;
        
        const results = await Mysql.query(query, [comment, user, post]);

        res.sendStatus(200);
    } catch (e) {
        //something went wrong, log the error, return a 500 Internal Server Error
        console.error(e);
        res.sendStatus(500);
    }
}

//list exported functions here
module.exports = {
    handleRoot,
    getPosts,
    putPost,
    deletePost,
    updatePost,
    putComment,
    getComments
}